==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/mzdy/zadostozuctovanizaloh.php <==
<?php
/**
 * UTF8
 * Roman.Szablatura RON Software 14.02.2019
 */

namespace Ron\RonPortal;

use mysql_xdevapi\Exception;
use Ron\DateUtils;
use Ron\DB\Database;


/**
 * Class ZadostOZuctovaniZaloh
 * @package Ron\RonPortal
 */
class ZadostOZuctovaniZaloh
{
    public $rc;
    public $osobniCislo;
    public $datumNastupu;

    public $rok;
    public $zadostPortalStav;
    //Žádost je za predchozi rok
    public $datumZadostiPortal;
    public $provestRocniVyuctovani;
    public $adresaBytovePotrebyUveru;
    public $osobyUplatnujiciUver;
    public $predchoziPrijmyKdyOdKoho;
    //Prohlášení je za aktuální rok
    public $datumProhlaseniPortal;

    //Nezdanitelné části základu daně
    public $hodnotaDaru;
    public $urokZeStavebSpor;
    public $penzijniPrip;
    public $zivotniPojisteni;
    public $clenskePrispevky;
    public $uhradZaZkousky;
    public $slevaNaPartnera;
    public $slevaNaPartneraZtp;

    //Udaje nerezidenta
    public $danovyNerezident;
    public $cisloDanoveIdentifikace;
    public $typDanovehoIdentifikatoru;
    public $typDanovehoIdentifikatoru_popis;
    public $statDanoveRezidence;
    public $statDanoveRezidence_popis;


    /**
     * @param Database $database
     * @param PracovniPomer $pp
     * @param $obdobi
     * @return ZadostOZuctovaniZaloh
     * @throws \Ron\DB\DBException
     */
    public static function nactiZadost($database, $pp, $obdobi)
    {
        $params = $database->createParameters();

        $rok = DateUtils::firstDayOfYear($obdobi);
        $rokProhlaseni = DateUtils::firstDayOfYear(time());

        /*SELECT Rok, RC, DatumProhlaseni, DatumProhlaseniPortal, ProhlaseniPortalStav, ProhlaseniPortal, DatumDodatecneProhlaseni,
        DatumDodatProhlPortal, DatumZadostiPortal, ZadostPortalStav, ProvestRocniVyuctovani, MesicVyuctovani, ZpusobPlatby,
        ZdanitelnyPrijemCelkem, ZdanitelnyPrijemZuctovany, ZdanitelnyPrijemRozdil, Pojistne, NezdanitelneCastky, ZakladDane,
        SkutecnaDan, SrazenaZaloha, DoplatekPreplatekDane, DoplatekNaDanovemBonusu, Prijem, PrijemZPredchZamest, PredchoziPrijmyKdyOdKoho,
        OpravaPrijmu, SocialniPojistne, SocPojZPredchZamest, OpravaSocPoj, ZdravotniPojistne, ZdravPojZPredchZamest, OpravaZdravPoj,
        SrazeneZalohyNaDan, SrazeneZalohyNaDanPredZam, OpravaZalohNaDan, VyplacenyStarobniDuchod, OdpocetZakladni, OpravaZakladnihoOdpoctu,
        OdpocetZakladniCelkem, OdpocetNaDeti, OdpocetNaDetiPredZam, OpravaOdpoctuNaDeti, DanoveZvyhodneni, DanoveZvyhodneniPredZam,
        OpravaDanovehoZvyhodneni, DanoveZvyhodneniCelkem, SlevaNaDani, SlevaNaDaniPredZam, OpravaSlevyNaDani, SlevaNaDaniCelkem,
        DanovyBonus, DanovyBonusPredZam, OpravaDanovehoBonusu, DanovyBonusCelkem, SlevaNaDaniRocni, DanovyBonusRocni, OdpocetNaZdravi,
        OdpocetNaZdraviPredZam, OpravaOdpoctuNaZdravi, OdpocetNaStudenta, OdpocetNaStudentaPredZam, OpravaOdpoctuNaStudenta,
        UplatnujeOdpocetPartnera, PrijemPartnera, PartnerZTPP, PocetMesicuOdpoctu, OdpocetNaPartnera, HodnotaDaru, OpravaHodnotDaru,
        HodnotaDaruCelkem, UrokyZeStavebSporeni, AdresaBytovePotrebyUveru, OsobyUplatnujiciUver, OpravaUrokuZeStavebSpor, OdpocetUroku,
        PenzijniPripojisteni, OpravaPenzijnihoPrip, OdpocetNaPenzijniPrip, UplatneneZivotniPojisteni, ZivotniPojisteni,
        OdpocetNaZivotniPojisteni, ClenskePrispevkyOdborum, OpravaClenskychPrispevku, OdpocetZaClenskePrispevku, UhradyZaZkousky,
        OpravaUhradZaZkousky, OdpocetZaZkousky, Schvaleno, VyuctovatProRC, VyuctovatProOsobniCislo, VyuctovatProDatumNastupu,
        UplatneneSlevyBezDZ, CelkemSlevyBezDZ, MesiceBezProhlaseni, DanovyNerezident, CisloDanoveIdentifikace, TypDanovehoIdentifikatoru,
        StatDanoveRezidence, UhrnPojistnehoNerezident, OpravaPojistnehoNerez, PojistneNerezidentCelkem, Poznamka, Skolkovne,
        OdpocetZaSkolkovne, PocetMesicuDite1, PocetMesicuDite2, PocetMesicuDite3, SolidarniDan, JeVybrano */

        $sql = "SELECT ";
        $sql .= " RVD.Rok, RVD.RC, RVD.DatumProhlaseni, RVD.ZadostPortalStav, RVD.DatumZadostiPortal, RVD.ProvestRocniVyuctovani, ";      //0..5
        $sql .= " RVD.CisloDanoveIdentifikace, RVD.TypDanovehoIdentifikatoru, RVD.DanovyNerezident, RVD.StatDanoveRezidence, ";     //6..9
        $sql .= " TypPrukazu.Popis, Stat.Popis, {fn_CASTWIDEMEMO(RVD.AdresaBytovePotrebyUveru)}, 
                    {fn_CASTWIDEMEMO(RVD.OsobyUplatnujiciUver)}, {fn_CASTWIDEMEMO(RVD.PredchoziPrijmyKdyOdKoho)}, ";     //10..14
        $sql .= "RVD.OpravaHodnotDaru, RVD.OpravaUrokuZeStavebSpor, RVD.OpravaPenzijnihoPrip, RVD.ZivotniPojisteni, 
                    RVD.OpravaClenskychPrispevku, RVD.OpravaUhradZaZkousky, "; //15..20
        $sql .= "RVD.SlevaPartnerObdobi, RVD.DatumProhlaseniPortal, ";          //21..22
        $sql .= "(Select DatumProhlaseniPortal From RocniVyuctovaniDane Where Rok = " . $params->addParameter($database->timestampToParam($rokProhlaseni)) .
            " AND RC = " . $params->addParameter($pp->rc) . ")";          //23

        $sql .= "FROM RocniVyuctovaniDane RVD 
                    LEFT JOIN TypPrukazu ON (RVD.TypDanovehoIdentifikatoru = TypPrukazu.Kod) 
                        LEFT JOIN Stat ON (Stat.Kod = RVD.StatDanoveRezidence)";

        $sql .= " WHERE RVD.RC = " . $params->addParameter($pp->rc);
        $sql .= " AND RVD.Rok = " . $params->addParameter($database->timestampToParam($rok));

        $cursor = $database->getSqlResult($sql, $params);

        if (!$row = $cursor->fetch()){
            throw new Exception(\Ron\ronText('zadost_nenalezena'));
        }

        $zadost = new ZadostOZuctovaniZaloh();
        $zadost->nactiHodnotyZRadku($database, $row);
        $cursor->close();

        return $zadost;
    }


    /**
     * @param Database $database
     * @param $row
     */
    public function nactiHodnotyZRadku($database, $row)
    {
        $this->rok = $database->stringToTimestamp($row[0]);
        $this->rc = $row[1];
        $this->zadostPortalStav = (int)$row[3];
        $this->datumZadostiPortal = $database->stringToTimestamp($row[4]);
        $this->provestRocniVyuctovani = (int)$row[5];

        $this->danovyNerezident = (int)$row[8];
        $this->cisloDanoveIdentifikace = $row[6];
        $this->typDanovehoIdentifikatoru = $row[7];
        $this->statDanoveRezidence = $row[9];
        $this->typDanovehoIdentifikatoru_popis = $row[10];
        $this->statDanoveRezidence = $row[11];
        $this->adresaBytovePotrebyUveru = $row[12];


        //osobyUplatnujiciUver
        $osobyUplatnujiciUverDoRadku = explode("\n", $row[13]);
        $poleOsobUplatnujicichUver = [];
        foreach ($osobyUplatnujiciUverDoRadku as $radek => $value){
            $radekZaznamu = explode("$-$", $value);
            $poleOsobUplatnujicichUver[] = $radekZaznamu;
        }
        $this->osobyUplatnujiciUver = $poleOsobUplatnujicichUver;

        //predchoziPrijmyKdyOdKoho
        $predchoziPrijmyRozdelenyDoRadku = explode("\n", $row[14]);
        $polePredchozichPrijmu = [];
        foreach ($predchoziPrijmyRozdelenyDoRadku as $radek => $value){
            $radekZaznamu = explode("$-$", $value);
            $polePredchozichPrijmu[] = $radekZaznamu;
        }
        $this->predchoziPrijmyKdyOdKoho = $polePredchozichPrijmu;

        $this->hodnotaDaru = $row[15];
        $this->urokZeStavebSpor = $row[16];
        $this->penzijniPrip = $row[17];
        $this->zivotniPojisteni = $row[18];
        $this->clenskePrispevky = $row[19];
        $this->uhradZaZkousky = $row[20];


        $this->slevaNaPartnera = explode(";", $row[21])[0];
        $this->slevaNaPartneraZtp = explode(";", $row[21])[1];
        $this->datumProhlaseniPortal = $database->stringToTimestamp($row[23]);
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/mzdy/zadostozuctovanizaloh.php <==
<?php
/**
 * UTF8
 * Roman.Szablatura RON Software 14.02.2019
 */

namespace Ron\RonPortal;

use Exception;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use function Ron\ronText;


/**
 * Class ZadostOZuctovaniZaloh
 * @package Ron\RonPortal
 */
class ZadostOZuctovaniZaloh
{
    const DOKUMENT_ZAMESTNAVATEL = 'predchozizamestnavatel';
    const DOKUMENT_SLEVA_PARTNER = 'slevanapartnera';
    const DOKUMENT_SKOLKOVNE = 'skolkovne';
    const DOKUMENT_SLEVA_ODECET = 'odecitatelnepolozky';

    public $rc;
    public $osobniCislo;
    public $datumNastupu;
    public $rodneCislo;

    public $rok;
    public $zadostPortalStav;
    //Žádost je za predchozi rok
    public $datumZadostiPortal;
    public $provestRocniVyuctovani;
    public $adresaBytovePotrebyUveru;
    public $osobyUplatnujiciUver;
    public $predchoziPrijmyKdyOdKoho;
    //Prohlášení je za aktuální rok
    public $datumProhlaseniPortal;
    public $schvaleno;
    public $zadostElektronicky;

    //Nezdanitelné části základu daně
    public $hodnotaDaru;
    public $urokZeStavebSpor;
    public $penzijniPrip;
    public $zivotniPojisteni;
    public $clenskePrispevky;
    public $uhradZaZkousky;
    public $slevaNaPartnera;
    public $slevaNaPartneraZtp;
    public $clenskePrispevkyNapoctene;
    public $hodnotaDaruNapoctena;
    public $zivotniPojisteniNapoctene;

    //Udaje nerezidenta
    public $danovyNerezident;
    public $cisloDanoveIdentifikace;
    public $typDanovehoIdentifikatoru;
    public $typDanovehoIdentifikatoru_popis;
    public $statDanoveRezidence;
    public $statDanoveRezidence_popis;

    public $poznamkaZadosti;

    /**
     * @param Database $database
     * @param PracovniPomer $pp
     * @param $obdobi
     * @return ZadostOZuctovaniZaloh
     * @throws DBException
     */
    public static function nactiZadost($database, $pp, $obdobi)
    {
        $params = $database->createParameters();

        $rok = DateUtils::firstDayOfYear($obdobi);

        $sql = "SELECT ";
        $sql .= " RVD.Rok, RVD.RC, RVD.DatumProhlaseni, RVD.ZadostPortalStav, RVD.DatumZadostiPortal, RVD.ProvestRocniVyuctovani, ";      //0..5
        $sql .= " RVD.CisloDanoveIdentifikace, RVD.TypDanovehoIdentifikatoru, RVD.DanovyNerezident, RVD.StatDanoveRezidence, ";     //6..9
        $sql .= " OsobniUdaj.RodneCislo, Stat.Popis, {fn_CASTWIDEMEMO(RVD.AdresaBytovePotrebyUveru)}, 
                    {fn_CASTWIDEMEMO(RVD.OsobyUplatnujiciUver)}, {fn_CASTWIDEMEMO(RVD.PredchoziPrijmyKdyOdKoho)}, ";     //10..14
        $sql .= "RVD.OpravaHodnotDaru, RVD.OpravaUrokuZeStavebSpor, RVD.OpravaPenzijnihoPrip, RVD.ZivotniPojisteni, 
                    RVD.OpravaClenskychPrispevku, RVD.OpravaUhradZaZkousky, "; //15..20
        $sql .= "RVD.SlevaPartnerObdobi, RVD.DatumProhlaseniPortal, RVD.ClenskePrispevkyOdborum, ";          //21..23

        $sql .= "RVD.HodnotaDaru, RVD.UplatneneZivotniPojisteni, RVD.PoznamkaProZamZadost, RVD.Schvaleno, RVD.ZadostElektronicky ";          //24 - 28

        $sql .= "FROM RocniVyuctovaniDane RVD
                 JOIN OsobniUdaj ON (OsobniUdaj.RC = RVD.RC) 
                 LEFT OUTER JOIN Stat ON (Stat.Kod = RVD.StatDanoveRezidence)";

        $sql .= " WHERE RVD.RC = " . $params->addParameter($pp->rc);
        $sql .= " AND RVD.Rok = " . $params->addParameter($database->timestampToParam($rok));

        $cursor = $database->getSqlResult($sql, $params);

        if (!$row = $cursor->fetch()){
            throw new Exception(ronText('zadost_nenalezena'));
        }

        $zadost = new ZadostOZuctovaniZaloh();
        $zadost->nactiHodnotyZRadku($database, $row);
        $cursor->close();

        return $zadost;
    }


    /**
     * @param Database $database
     * @param $row
     */
    public function nactiHodnotyZRadku($database, $row)
    {
        $this->rok = $database->stringToTimestamp($row[0]);
        $this->rc = $row[1];
        $this->zadostPortalStav = (int)$row[3];
        $this->datumZadostiPortal = $database->stringToTimestamp($row[4]);
        $this->provestRocniVyuctovani = (int)$row[5];

        $this->danovyNerezident = (int)$row[8];
        $this->cisloDanoveIdentifikace = $row[6];

        $this->typDanovehoIdentifikatoru = $row[7];
        switch ($this->typDanovehoIdentifikatoru) {
            case 0:
                $this->typDanovehoIdentifikatoru_popis = 'R';
                break;
            case 1:
                $this->typDanovehoIdentifikatoru_popis = 'D';
                break;
            case 2:
                $this->typDanovehoIdentifikatoru_popis = 'S';
                break;
            case 3:
                $this->typDanovehoIdentifikatoru_popis = 'J';
                break;
        }

        $this->statDanoveRezidence = $row[9];
        $this->statDanoveRezidence_popis = $row[11];
        $this->adresaBytovePotrebyUveru = $row[12];


        //osobyUplatnujiciUver
        $osobyUplatnujiciUverDoRadku = explode("\n", $row[13]);
        $poleOsobUplatnujicichUver = [];
        foreach ($osobyUplatnujiciUverDoRadku as $radek => $value){
            $radekZaznamu = explode("$-$", $value);
            $poleOsobUplatnujicichUver[] = $radekZaznamu;
        }
        $this->osobyUplatnujiciUver = $poleOsobUplatnujicichUver;

        //predchoziPrijmyKdyOdKoho
        $predchoziPrijmyRozdelenyDoRadku = explode("\n", $row[14]);
        $polePredchozichPrijmu = [];
        foreach ($predchoziPrijmyRozdelenyDoRadku as $radek => $value){
            $radekZaznamu = explode("$-$", $value);
            $polePredchozichPrijmu[] = $radekZaznamu;
        }
        $this->predchoziPrijmyKdyOdKoho = $polePredchozichPrijmu;

        $this->hodnotaDaru = (float)$row[15];
        $this->urokZeStavebSpor = (float)$row[16];
        $this->penzijniPrip = (float)$row[17];
        $this->zivotniPojisteni = (float)$row[18];
        $this->clenskePrispevky = (float)$row[19];
        $this->uhradZaZkousky = (float)$row[20];
        $this->clenskePrispevkyNapoctene = (float)$row[23];
        $this->hodnotaDaruNapoctena = (float)$row[24];
        $this->zivotniPojisteniNapoctene = (float)$row[25];

        if ($row[21] != '') {
            $this->slevaNaPartnera = explode(";", $row[21])[0];
            $this->slevaNaPartneraZtp = explode(";", $row[21])[1];
        }
        $this->datumProhlaseniPortal = $database->stringToTimestamp($row[22]);

        $this->poznamkaZadosti = $row[26];
        $this->schvaleno = $row[27];
        $this->zadostElektronicky = $row[28];
        $this->rodneCislo = $row[10];
    }
}
